/// <reference types="node" />
import { ConversationTurnError, ConversationTurnEvent, ConversationTurnResponse, StreamingResponseChunk } from './types.js';
import type { ContentBlock } from '@aws-sdk/client-bedrock-runtime';
import { GraphqlRequestExecutor } from './graphql_request_executor';
export type MutationResponseInput = {
    input: {
        associatedUserMessageId: string;
        conversationId: string;
        content: ContentBlock[];
        errors?: never;
    } | {
        associatedUserMessageId: string;
        conversationId: string;
        content?: never;
        errors: ConversationTurnError[];
    };
};
export type MutationStreamingResponseInput = {
    input: StreamingResponseChunk;
};
/**
 * This class is responsible for sending a response produced by Bedrock back to AppSync
 * in a form of mutation.
 */
export declare class ConversationTurnResponseSender {
    private readonly event;
    private readonly graphqlRequestExecutor;
    private readonly logger;
    /**
     * Creates conversation turn response sender.
     */
    constructor(event: ConversationTurnEvent, graphqlRequestExecutor?: GraphqlRequestExecutor, logger?: Console);
    sendResponse: (response: ConversationTurnResponse) => Promise<void>;
    sendResponseChunk: (chunk: StreamingResponseChunk) => Promise<void>;
    private createMutationRequest;
    private createStreamingMutationRequest;
    private serializeContent;
}
//# sourceMappingURL=conversation_turn_response_sender.d.ts.map